@@ -690,25 +690,38 @@ class vmmAddHardware(vmmGObjectUI):
 
     @staticmethod
     def populate_disk_bus_combo(vm, devtype, model):
+        # try to get supported disk bus types from domain capabilities
+        domcaps = vm.get_domain_capabilities()
+        disk_bus_types = None
+        if "bus" in domcaps.devices.disk.enum_names():
+            disk_bus_types = domcaps.devices.disk.get_enum("bus").get_values()
+
+        # if there are no disk bus types in domain capabilities fallback to
+        # old code
+        if not disk_bus_types:
+            disk_bus_types = []
+            if vm.is_hvm():
+                if not vm.get_xmlobj().os.is_q35():
+                    disk_bus_types.append("ide")
+                disk_bus_types.append("sata")
+                disk_bus_types.append("fdc")
+
+                if not vm.stable_defaults():
+                    disk_bus_types.append("scsi")
+                    disk_bus_types.append("usb")
+
+            if vm.get_hv_type() in ["qemu", "kvm", "test"]:
+                disk_bus_types.append("sd")
+                disk_bus_types.append("virtio")
+                if "scsi" not in disk_bus_types:
+                    disk_bus_types.append("scsi")
+
+            if vm.conn.is_xen() or vm.conn.is_test_conn():
+                disk_bus_types.append("xen")
+
         rows = []
-        if vm.is_hvm():
-            if not vm.get_xmlobj().os.is_q35():
-                rows.append(["ide", "IDE"])
-            rows.append(["sata", "SATA"])
-            rows.append(["fdc", _("Floppy")])
-
-            if not vm.stable_defaults():
-                rows.append(["scsi", "SCSI"])
-                rows.append(["usb", "USB"])
-
-        if vm.get_hv_type() in ["qemu", "kvm", "test"]:
-            rows.append(["sd", "SD"])
-            rows.append(["virtio", "VirtIO"])
-            if not rows.count(["scsi", "SCSI"]):
-                rows.append(["scsi", "SCSI"])
-
-        if vm.conn.is_xen() or vm.conn.is_test_conn():
-            rows.append(["xen", "Xen"])
+        for bus in disk_bus_types:
+            rows.append([bus, virtinst.VirtualDisk.pretty_disk_bus(bus)])
 
         model.clear()
 
@@ -1541,15 +1554,23 @@ class vmmAddHardware(vmmGObjectUI):
 
     def _validate_page_graphics(self):
         try:
-            (gtype, port,
-             tlsport, addr, passwd, keymap) = self._gfxdetails.get_values()
+            (gtype, port, tlsport, listen,
+             addr, passwd, keymap, gl, rendernode) = self._gfxdetails.get_values()
 
             self._dev = virtinst.VirtualGraphics(self.conn.get_backend())
             self._dev.type = gtype
-            self._dev.port = port
             self._dev.passwd = passwd
-            self._dev.listen = addr
-            self._dev.tlsPort = tlsport
+            self._dev.gl = gl
+            self._dev.rendernode = rendernode
+
+            if not listen or listen == "none":
+                self._dev.set_listen_none()
+            elif listen == "address":
+                self._dev.listen = addr
+                self._dev.port = port
+                self._dev.tlsPort = tlsport
+            else:
+                raise ValueError(_("invalid listen type"))
             if keymap:
                 self._dev.keymap = keymap
         except ValueError, e:
